@@ -14,10 +14,7 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/tf-module-stack",
-    "2.0.69",
-    __name__[0:-6],
-    "tf-module-stack@2.0.69.jsii.tgz",
+    "@cdktf/tf-module-stack", "3.0.3", __name__[0:-6], "tf-module-stack@3.0.3.jsii.tgz"
 )
 
 __all__ = [
